@@ -2952,9 +2952,14 @@ camel_mapi_store_ref_connection (CamelMapiStore *mapi_store,
 	g_return_val_if_fail (mapi_store->priv != NULL, NULL);
 
 	g_rec_mutex_lock (&mapi_store->priv->connection_lock);
-	if (!mapi_store->priv->connection)
+	if (!mapi_store->priv->connection) {
+		g_rec_mutex_unlock (&mapi_store->priv->connection_lock);
+
 		camel_mapi_store_connected (mapi_store, cancellable, error);
 
+		g_rec_mutex_lock (&mapi_store->priv->connection_lock);
+	}
+
 	conn = mapi_store->priv->connection;
 	if (conn)
 		g_object_ref (conn);
